spectralpy 
================================
[![Build](https://github.com/edmundsj/spectralpy/actions/workflows/python-package-conda.yml/badge.svg)](https://github.com/edmundsj/spectralpy/actions/workflows/python-package-conda.yml) [![docs](https://github.com/edmundsj/spectralpy/actions/workflows/build-docs.yml/badge.svg)](https://github.com/edmundsj/spectralpy/actions/workflows/build-docs.yml) [![codecov](https://codecov.io/gh/edmundsj/spectralpy/branch/main/graph/badge.svg?token=SmwvOS3MfV)](https://codecov.io/gh/edmundsj/spectralpy)

This module is for computing spectral properties of interest for EE
applications (i.e. single-sided power spectral density)

Documentation can be found
[here](https://edmundsj.github.io/spectralProcessing/)
